==> MBESS_0.0.9.tar.gz: MBESS/man/ci.sc.ancova.Rd <==
\name{ci.sc.ancova}
\alias{ci.sc.ancova}
\title{ Confidence interval for a standardized contrast in ANCOVA with one covariate}
\description{
Calculate the confidence interval for a standardized contrast in ANCOVA with one covariate. The standardizer
(i.e., the divisor) can be either the error standard deviation of the ANOVA model (i.e., the model excluding the covariate)
or of the ANCOVA model.
}
\usage{
ci.sc.ancova(Psi=NULL, means=NULL, s.anova = NULL, s.ancova, standardizer = "s.ancova", 
c.weights, n, x.bar, SSwithin.x, conf.level = 0.95)
}
\arguments{
  \item{Psi}{ unstandardized contrast of adjusted means }
  \item{means}{the vector that contains the adjusted mean of each group}
  \item{s.anova}{ the error standard deviation of the ANOVA model }
  \item{s.ancova}{ the error standard deviation of the ANCOVA model}
  \item{standardizer}{which error standard deviation the user wants to use, the value of which can be
  either \code{"s.ancova"} or \code{"s.anova"}}
  \item{c.weights}{ the contrast weights }
  \item{n}{ either a single number that indicates the sample size per group, or a vector that contains the
    sample size of each group}
  \item{x.bar}{ a vector that contains the group means of the covariate}
  \item{SSwithin.x}{ the sum of squares within groups obtained from the summary table for ANOVA on the covariate }
  \item{conf.level}{the desired confidence interval coverage, (i.e., 1 - Type I error rate)}
}

%\details{}

\value{
\item{stadardizer}{the divisor used in the standardization}
\item{psi.limit.lower}{the lower confidence limit of the standardized contrast}
\item{psi.limit.upper}{the upper confidence limit of the standardized contrast}

}

\references{ 
Maxwell, S. E., & Delaney, H. D. (2004). \emph{Designing experiments and analyzing data: A model comparison perspective}. Mahwah, NJ: Erlbaum.
}

\author{Keke Lai (Indiana University; \email{LaiK@Indiana.Edu})}

\note{
Be sure to use the error varaince and not its square root (i.e., the standard deviation of the errors).

If \code{n} receives a single number, that number is considered as the sample size per group. If \code{n}
is assigned to a vector, the vector is considered as the sample size of each group.

Be sure to use fractions not the integers to specify \code{c.weights}. For exmaple, in an ANCOVA of four groups, 
if the user wants to compare the mean of group 1 and 2 with the mean of group 3 and 4, \code{c.weights} should
be specified as c(0.5, 0.5, -0.5, -0.5) rather than c(1, 1, -1, -1). Make sure the sum of the contrast weights 
are zero.

The argument to be assigned to \code{standardizer} must be either \code{"s.ancova"} or \code{"s.anova"}. 
}

\seealso{\code{ci.c.ancova}, \code{ci.sc} }

\examples{
# Maxwell & Delaney (2004, pp. 428-468) offer an example that 30 depressive 
# individuals are randomly assigned to three groups, 10 in each, and ANCOVA 
# is performed on the posttest scores using the participants' pretest 
# scores as the covariate. The means of pretest scores of group 1 to 3 are 
# 17, 17,7, and 17,4, respectively, and the adjusted means of groups 1 to 3 
# are 7.5, 12, and 14, respectively. The error variance in ANCOVA is 29, 
# and the sum of squares within groups from ANOVA on the covariate is 
# 313.37. 

# To obtained the confidence interval for the standardized adjusted
# mean difference between group 1 and 2, using the ANCOVA error standard
# deviation:
ci.sc.ancova(means=c(7.5, 12, 14), s.ancova=29, c.weights=c(1,-1,0), 
n=10, x.bar=c(17, 17.7, 17.4), SSwithin.x=313.37)

}
\keyword{design }

==> MBESS_1.0.0.tar.gz: MBESS/man/ci.sc.ancova.Rd <==
\name{ci.sc.ancova}
\alias{ci.sc.ancova}
\title{ Confidence interval for a standardized contrast in ANCOVA with one covariate}
\description{
Calculate the confidence interval for a standardized contrast in ANCOVA with one covariate. The standardizer
(i.e., the divisor) can be either the error standard deviation of the ANOVA model (i.e., the model excluding the covariate)
or of the ANCOVA model.
}
\usage{
ci.sc.ancova(Psi=NULL, means=NULL, s.anova = NULL, s.ancova, 
standardizer = "s.ancova", c.weights, n, x.bar, SSwithin.x, 
conf.level = 0.95)
}
\arguments{
  \item{Psi}{ unstandardized contrast of adjusted means }
  \item{means}{the vector that contains the adjusted mean of each group}
  \item{s.anova}{ the error standard deviation of the ANOVA model }
  \item{s.ancova}{ the error standard deviation of the ANCOVA model}
  \item{standardizer}{which error standard deviation the user wants to use, the value of which can be
  either \code{"s.ancova"} or \code{"s.anova"}}
  \item{c.weights}{ the contrast weights }
  \item{n}{ either a single number that indicates the sample size per group, or a vector that contains the
    sample size of each group}
  \item{x.bar}{ a vector that contains the group means of the covariate}
  \item{SSwithin.x}{ the sum of squares within groups obtained from the summary table for ANOVA on the covariate }
  \item{conf.level}{the desired confidence interval coverage, (i.e., 1 - Type I error rate)}
}

%\details{}

\value{
\item{stadardizer}{the divisor used in the standardization}
\item{psi.limit.lower}{the lower confidence limit of the standardized contrast}
\item{psi.limit.upper}{the upper confidence limit of the standardized contrast}

}

\references{ 
Kelley, K. (2007). Constructing confidence intervals for standardized effect sizes: Theory, application, 
and implementation. \emph{Journal of Statistical Software, 20} (8), 1-24.

Kelley, K., \& Rausch, J. R. (2006). Sample size planning for the standardized mean difference: 
Accuracy in Parameter Estimation via narrow confidence intervals. P\emph{sychological Methods, 11} (4), 363-385.

Lai, K., \& Kelley, K. (2007). Sample size planning for standardized ANCOVA and ANOVA 
contrasts: Obtaining narrow confidence intervals. \emph{Manuscript submitted for publication}.

Steiger, J. H., \& Fouladi, R. T. (1997) Noncentrality interval estimation and the evaluation of
statistical methods. In L. L. Harlow, S. A. Mulaik, & J.H. Steiger (Eds.), \emph{What if there where
no significance tests?} (pp. 221-257). Mahwah, NJ: Lawrence Erlbaum. }

\author{Keke Lai (Indiana University; \email{LaiK@Indiana.Edu})}

\note{
Be sure to use the error varaince and not its square root (i.e., the standard deviation of the errors).

If \code{n} receives a single number, that number is considered as the sample size per group. If \code{n}
is assigned to a vector, the vector is considered as the sample size of each group.

Be sure to use fractions not the integers to specify \code{c.weights}. For exmaple, in an ANCOVA of four groups, 
if the user wants to compare the mean of group 1 and 2 with the mean of group 3 and 4, \code{c.weights} should
be specified as c(0.5, 0.5, -0.5, -0.5) rather than c(1, 1, -1, -1). Make sure the sum of the contrast weights 
are zero.

The argument to be assigned to \code{standardizer} must be either \code{"s.ancova"} or \code{"s.anova"}. 
}

\seealso{\code{ci.c.ancova}, \code{ci.sc} }

\examples{
# Maxwell & Delaney (2004, pp. 428-468) offer an example that 30 depressive 
# individuals are randomly assigned to three groups, 10 in each, and ANCOVA 
# is performed on the posttest scores using the participants' pretest 
# scores as the covariate. The means of pretest scores of group 1 to 3 are 
# 17, 17,7, and 17,4, respectively, and the adjusted means of groups 1 to 3 
# are 7.5, 12, and 14, respectively. The error variance in ANCOVA is 29, 
# and the sum of squares within groups from ANOVA on the covariate is 
# 313.37. 

# To obtained the confidence interval for the standardized adjusted
# mean difference between group 1 and 2, using the ANCOVA error standard
# deviation:
ci.sc.ancova(means=c(7.5, 12, 14), s.ancova=29, c.weights=c(1,-1,0), 
n=10, x.bar=c(17, 17.7, 17.4), SSwithin.x=313.37)

}
\keyword{design }
